@@ -98,6 +98,8 @@ class Oracle:
                 sublist = pd.concat([sublist, failed], ignore_index=True)
 
             sublist = sublist[sublist['chr1'] == chromosome]
+            if sublist.shape[0] == 0:
+                continue
             sublist = sublist.reset_index(drop=True)
             batch = np.zeros((len(sublist), self.__width, self.__width, 1))
 
