@@ -11,11 +11,6 @@ from hicml.PredictionHandler import find_bound_in_connected_components, find_max
 from hicml.DataStructures import LockedList, AggregatedMatrix
 
 
-def is_too_close_to_diagonal(row_start, column_start, row_end, column_end, resolution):
-    return abs(row_start - column_start) < 2 * resolution and \
-           abs(row_end - column_end) < 2 * resolution
-
-
 class DeploySpears:
     def __init__(self, all_model_sets: list, batch_size: int, num_straw_workers: int, filepath: str,
                  resolution: int, max_examples_in_ram: int, matrix_width: int, threshold: float,
@@ -273,4 +268,3 @@ class DeploySpears:
         print('Starting NMS', flush=True)
         for k in range(self.__num_output_channels + 1):
             self.__nms_handlers[k].do_nms_and_print_to_file(self.__out_files[k])
-
